@@ -66,7 +66,7 @@ public:
     bool isNew( const QString& app, int noteId ) const;
     bool isModified( const QString& app, const QString& name ) const;
     bool isModified( const QString& app, int noteId ) const;
-
+    
     bool commitData( QSessionManager& );
     bool saveState( QSessionManager& );
 
@@ -83,13 +83,15 @@ protected slots:
     void slotNoteKilled( const QString& name );
     void slotNoteRenamed( const QString& oldname, const QString& newname );
 
+    void slotQuit();
+    
 private slots:
     void updateNoteActions();
 
 private:
     KNote* noteById( int id ) const;
     void showNote( KNote* note ) const;
-    void saveNotes() const;
+    void saveNotes( bool display ) const;
 
     QDict<KNote>      m_noteList;
     QPtrList<KAction> m_noteActions;
