@@ -17,7 +17,7 @@
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
-// $Id: koeventviewer.cpp,v 1.21.2.1 2002/03/29 19:09:02 cschumac Exp $
+// $Id: koeventviewer.cpp,v 1.21.2.3 2002/12/21 06:16:56 mueller Exp $
 
 #include <qcstring.h>
 
@@ -27,6 +27,7 @@
 #include <libkcal/todo.h>
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <kprocess.h>
 #include <krun.h>
 
 #ifndef KORG_NODCOP
@@ -80,7 +81,7 @@ void KOEventViewer::setSource(const QString& n)
       QString iconPath = iconLoader->iconPath("go",KIcon::Small);
       KOrganizer::setStartedKAddressBook(true);
       tmpStr = "kaddressbook --editor-only --uid ";
-      tmpStr += n.mid(6);
+      tmpStr += KShellProcess::quote(n.mid(6));
       bool result = KRun::runCommand(tmpStr,"KAddressBook",iconPath);
       return;
     }
