@@ -1,6 +1,27 @@
-// $Id: koincidenceeditor.cpp,v 1.3 2001/05/09 14:53:46 mlaurent Exp $
+/*
+    This file is part of KOrganizer.
+    Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
 
-#include <stdio.h>
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    As a special exception, permission is given to link this program
+    with any edition of Qt, and distribute the resulting executable,
+    without including the source code for Qt in the source distribution.
+*/
+
+// $Id: koincidenceeditor.cpp,v 1.6 2002/01/16 17:01:09 cschumac Exp $
 
 #include <qtooltip.h>
 #include <qframe.h>
@@ -9,13 +30,8 @@
 #include <qwidgetstack.h>
 #include <qdatetime.h>
 
-#include <kdatepik.h>
-#include <kiconloader.h>
-#include <kapp.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <ktoolbarbutton.h>
-#include <kstddirs.h>
 
 #include "categoryselectdialog.h"
 #include "koprefs.h"
@@ -42,24 +58,7 @@ KOIncidenceEditor::~KOIncidenceEditor()
   delete mCategoryDialog;
 }
 
-void KOIncidenceEditor::init()
-{
-  setupGeneralTab();
-  setupDetailsTab();
-  setupCustomTabs();
-}
-
-void KOIncidenceEditor::setupGeneralTab()
-{
-  QFrame *topFrame = addPage(i18n("General"));
-
-  QBoxLayout *topLayout = new QVBoxLayout(topFrame);
-  topLayout->setMargin(marginHint());
-
-  topLayout->addWidget(setupGeneralTabWidget(topFrame));
-}
-
-void KOIncidenceEditor::setupDetailsTab()
+void KOIncidenceEditor::setupAttendeesTab()
 {
   QFrame *topFrame = addPage(i18n("Attendees"));
 
