@@ -22,7 +22,7 @@
     without including the source code for Qt in the source distribution.
 */
 
-// $Id: komailclient.cpp,v 1.29 2002/03/12 22:03:18 mueller Exp $
+// $Id: komailclient.cpp,v 1.29.2.1 2002/12/06 15:47:00 waba Exp $
 
 #include <unistd.h>
 #include <stdio.h>
@@ -34,6 +34,7 @@
 #include <kurl.h>
 #include <kapplication.h>
 #include <dcopclient.h>
+#include <kprocess.h>
 
 #include <libkcal/event.h>
 
@@ -116,17 +117,16 @@ bool KOMailClient::send(const QString &from,const QString &to,
       command = KStandardDirs::findExe(QString::fromLatin1("mail"));
       if (command.isNull()) return false; // give up
 
-      command.append(QString::fromLatin1(" -s \x22"));
-      command.append(subject);
-      command.append(QString::fromLatin1("\x22"));
+      command.append(QString::fromLatin1(" -s "));
+      command.append(KShellProcess::quote(subject));
 
       if (bcc) {
         command.append(QString::fromLatin1(" -b "));
-        command.append(from);
+        command.append(KShellProcess::quote(from));
       }
 
       command.append(" ");
-      command.append(to);
+      command.append(KShellProcess::quote(to));
 
       needHeaders = false;
     }
