@@ -21,7 +21,7 @@
     without including the source code for Qt in the source distribution.
 */
 
-// $Id: kotodoview.cpp,v 1.70.2.1 2002/04/04 12:03:05 cschumac Exp $
+// $Id: kotodoview.cpp,v 1.70.2.2 2002/08/01 20:57:08 cschumac Exp $
 
 #include <qlayout.h>
 #include <qheader.h>
@@ -272,7 +272,7 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   // Double clicking conflicts with opening/closing the subtree                   
   QObject::connect(mTodoListView,SIGNAL(doubleClicked(QListViewItem *)),
                    this,SLOT(showItem(QListViewItem *)));
-  QObject::connect(mTodoListView,SIGNAL(rightButtonClicked ( QListViewItem *,
+  QObject::connect(mTodoListView,SIGNAL(contextMenuRequested ( QListViewItem *,
                    const QPoint &, int )),
                    this,SLOT(popupMenu(QListViewItem *,const QPoint &,int)));
   QObject::connect(mTodoListView,SIGNAL(clicked(QListViewItem *)),
