@@ -16,7 +16,7 @@
 
 #line 1 "parsedate.y"
 
-/* $Revision: 1.4 $
+/* $Revision: 1.4.8.3 $
 **
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
 **  at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -1676,7 +1676,7 @@ main(ac, av)
     for ( ; ; ) {
 	(void)printf("\t> ");
 	(void)fflush(stdout);
-	if (gets(buff) == NULL || buff[0] == '\n')
+	if (fgets(stdin,buff,sizeof(buff)-1) == NULL || buff[0] == '\n')
 	    break;
 #if YYDEBUG
 	if (strcmp(buff, "yydebug") == 0) {
