@@ -32,7 +32,7 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-static const char *TodoConduit_id = "$Id: todo-conduit.cc,v 1.10.2.1 2002/04/28 12:58:54 kainhofe Exp $";
+static const char *TodoConduit_id = "$Id: todo-conduit.cc,v 1.10.2.3 2002/06/16 11:03:14 kainhofe Exp $";
 
 #include <options.h>
 #include <unistd.h>
@@ -103,7 +103,7 @@ KCal::Incidence *TodoConduitPrivate::findIncidence(recordid_t id)
 	KCal::Todo *todo = fAllTodos.first();
 	while(todo)
 	{
-		if (todo->pilotId() == id) return todo;
+		if ((recordid_t)(todo->pilotId()) == id) return todo;
 		todo = fAllTodos.next();
 	}
 
@@ -131,7 +131,7 @@ KCal::Incidence *TodoConduitPrivate::getNextModifiedIncidence()
 	{
 		e=fAllTodos.next();
 	}
-	while (e && e->syncStatus()==KCal::Incidence::SYNCNONE)
+	while (e && e->syncStatus()!=KCal::Incidence::SYNCMOD)
 	{
 		e=fAllTodos.next();
 	}
@@ -158,17 +158,16 @@ TodoConduit::~TodoConduit()
 //	FUNCTIONSETUP;
 }
 
+const QString TodoConduit::getTitle(PilotAppCategory*de)
+{
+	PilotTodoEntry*d=dynamic_cast<PilotTodoEntry*>(de);
+	if (d) return QString(d->getDescription());
+	return "";
+}
 
 PilotRecord*TodoConduit::recordFromIncidence(PilotAppCategory*de, const KCal::Incidence*e)
 {
-	FUNCTIONSETUP;
-	if (!de || !e)
-	{
-#ifdef DEBUG
-		DEBUGCONDUIT<<fname<<": got null entry or null incidence."<<endl;
-#endif
-		return NULL;
-	}
+	// don't need to check for null pointers here, the recordFromIncidence(PTE*, KCal::Todo*) will do that.	
 	return recordFromIncidence(dynamic_cast<PilotTodoEntry*>(de), dynamic_cast<const KCal::Todo*>(e));
 }
 
@@ -208,7 +207,6 @@ PilotRecord*TodoConduit::recordFromIncidence(PilotTodoEntry*de, const KCal::Todo
 	// what we call description pilot puts as a separate note
 	de->setNote(todo->description());
 
-DEBUGCONDUIT<<"-------- "<<todo->summary()<<endl;
 	return de->pack();
 }
 
@@ -230,13 +228,6 @@ KCal::Todo *TodoConduit::incidenceFromRecord(KCal::Todo *e, const PilotTodoEntry
 		DEBUGCONDUIT<<fname<<": null todo entry given. skipping..."<<endl;
 #endif
 		return NULL;
-		// no event was found, so we need to add one with some initial info
-		// TODO: does this make sense and do I really have to add the todo, or just exit out of this function?
-//		vtodo = new KCal::Todo;
-//		fCalendar->addTodo(vtodo);
-//		calendar()->addTodo(vtodo);
-//		vtodo->setPilotId(de->getID());
-//		vtodo->setSyncStatus(KCal::Incidence::SYNCNONE);
 	}
 
 	e->setOrganizer(fCalendar->getEmail());
@@ -276,6 +267,12 @@ KCal::Todo *TodoConduit::incidenceFromRecord(KCal::Todo *e, const PilotTodoEntry
 
 
 // $Log: todo-conduit.cc,v $
+// Revision 1.10.2.3  2002/06/16 11:03:14  kainhofe
+// merged in some changes from the HEAD branch. Also fixed someproblems with retrieving a db from the palm
+//
+// Revision 1.10.2.2  2002/06/15 13:34:14  kainhofe
+// merging in changes from the HEAD branch that should go into 3.0.2
+//
 // Revision 1.10.2.1  2002/04/28 12:58:54  kainhofe
 // Calendar conduit now works, no memory leaks, timezone still shifted. Todo conduit mostly works, for my large list it crashes when saving the calendar file.
 //
