@@ -86,6 +86,8 @@ public:
 	virtual ~TodoConduit();
    
 protected:
+	virtual const QString getTitle(PilotAppCategory*de);
+	
 	virtual const QString configGroup() { return ToDoConduitFactory::group; };
 	virtual const QString dbname() { return "ToDoDB"; };
 
@@ -105,6 +107,9 @@ protected:
 } ;
 
 // $Log: todo-conduit.h,v $
+// Revision 1.4.2.3  2002/06/16 11:03:14  kainhofe
+// merged in some changes from the HEAD branch. Also fixed someproblems with retrieving a db from the palm
+//
 // Revision 1.4.2.2  2002/05/01 21:11:49  kainhofe
 // Reworked the settings dialog, added various different sync options
 //
