@@ -27,7 +27,7 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-static const char *vcalconduit_id = "$Id: vcal-conduit.cc,v 1.51.2.3 2002/04/28 12:58:54 kainhofe Exp $";
+static const char *vcalconduit_id = "$Id: vcal-conduit.cc,v 1.51.2.5 2002/06/16 11:03:14 kainhofe Exp $";
 
 #include <options.h>
 #include <unistd.h>
@@ -103,7 +103,7 @@ KCal::Incidence *VCalConduitPrivate::findIncidence(recordid_t id)
 	KCal::Event *event = fAllEvents.first();
 	while (event!=0)
 	{
-		if (event->pilotId() == id) return event;
+		if ((recordid_t)event->pilotId() == id) return event;
 		event = fAllEvents.next();
 	}
 	return 0L;
@@ -161,6 +161,14 @@ VCalConduitPrivateBase* VCalConduit::newVCalPrivate(KCal::Calendar *fCalendar) {
 	return new VCalConduitPrivate(fCalendar);
 };
 
+const QString VCalConduit::getTitle(PilotAppCategory*de)
+{
+	PilotDateEntry*d=dynamic_cast<PilotDateEntry*>(de);
+	if (d) return QString(d->getDescription());
+	return "";
+}
+
+
 
 PilotRecord*VCalConduit::recordFromIncidence(PilotAppCategory*de, const KCal::Incidence*e)
 {
@@ -679,6 +687,12 @@ void VCalConduit::setExceptions(PilotDateEntry *dateEntry, const KCal::Event *ve
 }
 
 // $Log: vcal-conduit.cc,v $
+// Revision 1.51.2.5  2002/06/16 11:03:14  kainhofe
+// merged in some changes from the HEAD branch. Also fixed someproblems with retrieving a db from the palm
+//
+// Revision 1.51.2.4  2002/06/15 13:34:14  kainhofe
+// merging in changes from the HEAD branch that should go into 3.0.2
+//
 // Revision 1.51.2.3  2002/04/28 12:58:54  kainhofe
 // Calendar conduit now works, no memory leaks, timezone still shifted. Todo conduit mostly works, for my large list it crashes when saving the calendar file.
 //
