@@ -30,16 +30,19 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-static const char *vcalconduitbase_id = "$Id: vcal-conduitbase.cc,v 1.1.2.4 2002/05/03 19:08:52 kainhofe Exp $";
+static const char *vcalconduitbase_id = "$Id: vcal-conduitbase.cc,v 1.1.2.7 2002/06/16 11:03:14 kainhofe Exp $";
 
 #include <options.h>
 #include <unistd.h>
 
 #include <qdatetime.h>
 #include <qtimer.h>
+#include <qdir.h>
+#include <qfileinfo.h>
 
 #include <pilotUser.h>
 #include <kconfig.h>
+#include <kmessagebox.h>
 
 #include <calendar.h>
 #include <calendarlocal.h>
@@ -67,7 +70,6 @@ static const char *vcalconduitbase_id = "$Id: vcal-conduitbase.cc,v 1.1.2.4 2002
 #include <pilotLocalDatabase.h>
 #include <pilotDateEntry.h>
 
-//#include "vcal-conduitbase.h"
 #include "vcal-factorybase.h"
 #include "vcal-conduitbase.moc"
 
@@ -128,8 +130,6 @@ VCalConduitBase::VCalConduitBase(KPilotDeviceLink *d,
 	const QStringList &a) :
 	ConduitAction(d,n,a),
 	fCalendar(0L),
-	fCurrentDatabase(0L),
-	fBackupDatabase(0L),
 	fP(0L)
 {
 	FUNCTIONSETUP;
@@ -142,8 +142,6 @@ VCalConduitBase::~VCalConduitBase()
 	FUNCTIONSETUP;
 
 	KPILOT_DELETE(fP);
-	KPILOT_DELETE(fCurrentDatabase);
-	KPILOT_DELETE(fBackupDatabase);
 	KPILOT_DELETE(fCalendar);
 }
 
@@ -165,7 +163,7 @@ VCalConduitBase::~VCalConduitBase()
 
 
    The sync process is as follows (for a fast sync):
-	1) syncRecord goes through all records on Palm (just the modified one are necessary), find it
+	1) syncPalmRecToPC goes through all records on Palm (just the modified one are necessary), find it
 	   in the backupDB. The following handles ([NMD],*)
 	   a) if it doesn't exist and was not deleted, add it to the calendar and the backupDB
 	   b) if it exists and was not deleted,
@@ -202,20 +200,9 @@ there are two special cases: a full and a first sync.
 
 /* virtual */ void VCalConduitBase::exec()
 {
-// TODO: don't set
-	//debug_level=0;
 	FUNCTIONSETUP;
 
-//	bool loadSuccesful = true;
 	KPilotUser*usr;
-	KConfig korgcfg( locate( "config", "korganizerrc" ) );
-	QString tz;
-	// this part taken from adcalendarbase.cpp:
-	korgcfg.setGroup( "Time & Date" );
-	tz = korgcfg.readEntry( "TimeZoneId" );
-#ifdef DEBUG
-	DEBUGCONDUIT << fname<<": KOrganizer's time zone = "<<tz<<endl;
-#endif
 
 	if (!fConfig)
 	{
@@ -235,81 +222,68 @@ there are two special cases: a full and a first sync.
 		emit syncDone(this);
 		return;
 	}
-
-	fConfig->setGroup(configGroup());
-
-	fCalendarFile = fConfig->readEntry(VCalConduitFactoryBase::calendarFile);
-	syncAction = fConfig->readNumEntry(VCalConduitFactoryBase::syncAction);
-	nextSyncAction = fConfig->readNumEntry(VCalConduitFactoryBase::nextSyncAction);
-	fConfig->writeEntry(VCalConduitFactoryBase::nextSyncAction, 0);
-	conflictResolution = fConfig->readNumEntry(VCalConduitFactoryBase::conflictResolution);
-	archive = fConfig->readBoolEntry(VCalConduitFactoryBase::archive);
+	
+	readConfig();
 
 	// don't do a first sync by default in any case, only when explicitely requested, or the backup
 	// database or the alendar are empty.
 	fFirstTime = (syncAction==SYNC_FIRST /*|| nextSyncAction!=0*/);
 	usr=fHandle->getPilotUser();
 	// changing the PC or using a different Palm Desktop app causes a full sync
-	// User gethostid for this, since JPilot uses 1+(2000000000.0*random()/(RAND_MAX+1.0))
+	// Use gethostid for this, since JPilot uses 1+(2000000000.0*random()/(RAND_MAX+1.0))
 	// as PC_ID, so using JPilot and KPilot is the same as using two differenc PCs
 	fFullSync = (syncAction==SYNC_FULL) ||
 		((usr->getLastSyncPC()!=(unsigned long) gethostid()) && fConfig->readBoolEntry(VCalConduitFactoryBase::fullSyncOnPCChange, true));
 
-#ifdef DEBUG
-	DEBUGCONDUIT << fname
-		<< ": Using calendar file "
-		<< fCalendarFile
-		<< endl;
-#endif
-
-	fCurrentDatabase = new PilotSerialDatabase(pilotSocket(), dbname(), this, dbname());
-	fBackupDatabase = new PilotLocalDatabase(dbname());
-	fCalendar = new KCal::CalendarLocal(tz);
-	if (!fCurrentDatabase || !fBackupDatabase || !fCalendar) goto error;
-
+	fLocalDatabase = new PilotLocalDatabase(dbname());
+	if (!fLocalDatabase ) goto error;
+ 
 	// if there is no backup db yet, fetch it from the palm, open it and set the full sync flag.
-	if (!fBackupDatabase->isDBOpen() )
+	if (!fLocalDatabase->isDBOpen() )
 	{
+		QString dbPath(dynamic_cast<PilotLocalDatabase*>(fLocalDatabase)->dbPathName());
+		KPILOT_DELETE(fLocalDatabase);
 #ifdef DEBUG
-		DEBUGCONDUIT << "Backup database "<<fBackupDatabase->dbPathName()<<" could not be opened. Will fetch a copy from the palm and do a full sync"<<endl;
+		DEBUGCONDUIT << "Backup database "<<dbPath<<" could not be opened. Will fetch a copy from the palm and do a full sync"<<endl;
 #endif
 		struct DBInfo dbinfo;
 		char nm[50];
 		strncpy(&nm[0], dbname().latin1(), sizeof(nm));
-		DEBUGCONDUIT << dbinfo.name<<endl;
 		fHandle->findDatabase(&nm[0], &dbinfo);
-		DEBUGCONDUIT << dbinfo.name<<endl;
-		if (!fHandle->retrieveDatabase(fBackupDatabase->dbPathName(), &dbinfo) ) goto error;
-		KPILOT_DELETE(fBackupDatabase);
-		fBackupDatabase = new PilotLocalDatabase(dbname());
-		if (!fBackupDatabase || !fBackupDatabase->isDBOpen()) goto error;
+
+#ifdef DEBUG
+			DEBUGCONDUIT <<"Found Palm database: "<<dbinfo.name<<endl
+					<<"type = "<< dbinfo.type<<endl
+					<<"creator = "<< dbinfo.creator<<endl
+					<<"version = "<< dbinfo.version<<endl
+					<<"index = "<< dbinfo.index<<endl;
+#endif
+		// make sure the dir for the backup db really exists!
+		QFileInfo fi(dbPath);
+		if (!fi.exists()) {
+			QDir d(fi.dir(TRUE));
+#ifdef DEBUG
+			DEBUGCONDUIT <<"Creating backup directory "<<d.absPath()<<endl;
+#endif
+			d.mkdir(d.absPath());
+		}
+		if (!fHandle->retrieveDatabase(dbPath, &dbinfo) ) goto error;
+		fLocalDatabase = new PilotLocalDatabase(dbname());
+		if (!fLocalDatabase || !fLocalDatabase->isDBOpen()) goto error;
 		fFullSync=true;
 	}
 
+	fDatabase = new PilotSerialDatabase(pilotSocket(), dbname(), this, dbname());
+	if (!fDatabase ) goto error;
+	
 	// Handle lots of error cases.
-	if (!fCurrentDatabase->isDBOpen() ||
-		 !fBackupDatabase->isDBOpen()) goto error;
+	if (!fDatabase->isDBOpen() ||
+		 !fLocalDatabase->isDBOpen()) goto error;
 
+//	if (!openDatabases(dbname(), &fFullSync) ) goto error;
+	
+	if (!openCalendar() ) goto error;
 
-	// TODO: fix the time zone setting: How do I get the correct setting???
-	//       I have to set this explicitely, otherwise, all entries will be in GMT...
-//	fCalendar->setTimeZone(0);
-
-
-	// if there is no calendar yet, use a first sync..
-	// the calendar is initialized, so nothing more to do...
-	if (!fCalendar->load(fCalendarFile) )
-	{
-#ifdef DEBUG
-		DEBUGCONDUIT << "calendar file "<<fCalendarFile<<" could not be opened. Will create a new one"<<endl;
-#endif
-		fFirstTime=true;
-	}
-
-	fP = newVCalPrivate(fCalendar);
-   if (!fP) goto error;
-	fP->updateIncidences();
-	if (fP->count()<1) fFullSync=true;
 
 #ifdef DEBUG
 	DEBUGCONDUIT<<fname<<": fullsync="<<fFullSync<<", firstSync="<<fFirstTime<<endl;
@@ -323,24 +297,24 @@ there are two special cases: a full and a first sync.
 	case 2:
 		// TODO: Clear the palm and backup database??? Or just add the new items ignore
 		// the Palm->PC side and leave the existing items on the palm?
-		QTimer::singleShot(0, this, SLOT(syncIncidence()));
+		QTimer::singleShot(0, this, SLOT(syncPCRecToPalm()));
 		break;
 	case 1:
 		// TODO: Clear the backup database and the calendar, update fP
 		//       or just add the palm items and leave the PC ones there????
 	default:
-		QTimer::singleShot(0, this, SLOT(syncRecord()));
+		QTimer::singleShot(0, this, SLOT(syncPalmRecToPC()));
 	}
 	return;
 
 error:
-	if (!fCurrentDatabase)
+	if (!fDatabase)
 	{
 		kdWarning() << k_funcinfo
 			<< ": Couldn't open database on Pilot"
 			<< endl;
 	}
-	if (!fBackupDatabase)
+	if (!fLocalDatabase)
 	{
 		kdWarning() << k_funcinfo
 			<< ": Couldn't open local copy"
@@ -349,26 +323,84 @@ error:
 
 	emit logError(i18n("Couldn't open the calendar databases."));
 
-	KPILOT_DELETE(fCurrentDatabase);
-	KPILOT_DELETE(fBackupDatabase);
 	KPILOT_DELETE(fCalendar);
-   KPILOT_DELETE(fP);
+	KPILOT_DELETE(fP);
 	emit syncDone(this);
 }
 
 
-void VCalConduitBase::syncRecord()
+/* virtual */ void VCalConduitBase::readConfig()
+{
+	fConfig->setGroup(configGroup());
+
+	fCalendarFile = fConfig->readEntry(VCalConduitFactoryBase::calendarFile);
+	syncAction = fConfig->readNumEntry(VCalConduitFactoryBase::syncAction);
+	nextSyncAction = fConfig->readNumEntry(VCalConduitFactoryBase::nextSyncAction);
+	fConfig->writeEntry(VCalConduitFactoryBase::nextSyncAction, 0);
+	conflictResolution = fConfig->readNumEntry(VCalConduitFactoryBase::conflictResolution);
+	archive = fConfig->readBoolEntry(VCalConduitFactoryBase::archive);
+}
+	
+
+/* virtual */ bool VCalConduitBase::openCalendar()
+{
+	FUNCTIONSETUP;
+	
+	KConfig korgcfg( locate( "config", "korganizerrc" ) );
+	// this part taken from adcalendarbase.cpp:
+	korgcfg.setGroup( "Time & Date" );
+	QString tz(korgcfg.readEntry( "TimeZoneId" ) );
+#ifdef DEBUG
+	DEBUGCONDUIT << fname<<": KOrganizer's time zone = "<<tz<<endl;
+#endif
+
+
+#ifdef DEBUG
+	DEBUGCONDUIT << fname
+		<< ": Using calendar file "
+		<< fCalendarFile
+		<< endl;
+#endif
+
+	fCalendar = new KCal::CalendarLocal(tz);
+	if ( !fCalendar) 
+	{
+#ifdef DEBUG
+		DEBUGCONDUIT << fname << ":Cannot initialize calendar object"<<endl;
+#endif
+		return false;
+	}
+
+	// if there is no calendar yet, use a first sync..
+	// the calendar is initialized, so nothing more to do...
+	if (!fCalendar->load(fCalendarFile) )
+	{
+#ifdef DEBUG
+		DEBUGCONDUIT << "calendar file "<<fCalendarFile<<" could not be opened. Will create a new one"<<endl;
+#endif
+		fFirstTime=true;
+	}
+
+	fP = newVCalPrivate(fCalendar);
+	if (!fP) return false;
+	fP->updateIncidences();
+	if (fP->count()<1) fFullSync=true;
+	
+	return (fCalendar && fP);
+}
+
+void VCalConduitBase::syncPalmRecToPC()
 {
 	FUNCTIONSETUP;
 
 	PilotRecord *r;
 	if (fFirstTime || fFullSync)
 	{
-		r = fCurrentDatabase->readRecordByIndex(pilotindex++);
+		r = fDatabase->readRecordByIndex(pilotindex++);
 	}
 	else
 	{
-		r = fCurrentDatabase->readNextModifiedRec();
+		r = fDatabase->readNextModifiedRec();
 	}
 	PilotRecord *s = 0L;
 
@@ -382,18 +414,17 @@ void VCalConduitBase::syncRecord()
 		}
 		else
 		{
-			QTimer::singleShot(0 ,this,SLOT(syncIncidence()));
+			QTimer::singleShot(0 ,this,SLOT(syncPCRecToPalm()));
 			return;
 		}
 	}
 
 	// first, delete the dirty flag from the palm database. Prolly should do this after the record has been synced
 //	r->setAttrib(r->getAttrib() & ~dlpRecAttrDirty);
-//	fCurrentDatabase->writeRecord(r);
+//	fDatabase->writeRecord(r);
 	bool archiveRecord=(r->getAttrib() & dlpRecAttrArchived);
 
-	s = fBackupDatabase->readRecordById(r->getID());
-	// TODO: use the archive flag, too
+	s = fLocalDatabase->readRecordById(r->getID());
 	if (!s || fFirstTime)
 	{
 #ifdef DEBUG
@@ -405,7 +436,10 @@ void VCalConduitBase::syncRecord()
 #endif
 		if (!r->isDeleted() || (archive && archiveRecord))
 		{
-			addRecord(r);
+			KCal::Incidence*e=addRecord(r);
+			if (archive && archiveRecord )  {
+				e->setSyncStatus(KCal::Incidence::SYNCDEL);
+			}
 		}
 	}
 	else
@@ -430,11 +464,11 @@ void VCalConduitBase::syncRecord()
 	KPILOT_DELETE(r);
 	KPILOT_DELETE(s);
 
-	QTimer::singleShot(0,this,SLOT(syncRecord()));
+	QTimer::singleShot(0,this,SLOT(syncPalmRecToPC()));
 }
 
 
-void VCalConduitBase::syncIncidence()
+void VCalConduitBase::syncPCRecToPalm()
 {
 	FUNCTIONSETUP;
 	KCal::Incidence*e=0L;
@@ -459,7 +493,7 @@ void VCalConduitBase::syncIncidence()
 		DEBUGCONDUIT<<fname<<": Description: "<<e->summary()<<endl;
 #endif
 	PilotRecord *s=0L;
-	if (ix>0 && (s=fCurrentDatabase->readRecordById(ix)))
+	if (ix>0 && (s=fDatabase->readRecordById(ix)))
 	{
 		if (e->syncStatus()==KCal::Incidence::SYNCDEL)
 		{
@@ -480,15 +514,15 @@ void VCalConduitBase::syncIncidence()
 #endif
 		addPalmRecord(e);
 	}
-	QTimer::singleShot(0, this, SLOT(syncIncidence()));
+	QTimer::singleShot(0, this, SLOT(syncPCRecToPalm()));
 }
 
 
 void VCalConduitBase::syncDeletedIncidence()
 {
-	FUNCTIONSETUP;
+//	FUNCTIONSETUP;
 
-	PilotRecord *r = fBackupDatabase->readRecordByIndex(pilotindex++);
+	PilotRecord *r = fLocalDatabase->readRecordByIndex(pilotindex++);
 	if (!r || fFullSync || fFirstTime)
 	{
 		QTimer::singleShot(0 ,this,SLOT(cleanup()));
@@ -499,16 +533,16 @@ void VCalConduitBase::syncDeletedIncidence()
 	if (!e)
 	{
 		// entry was deleted from Calendar, so delete it from the palm
-		PilotRecord*s=fBackupDatabase->readRecordById(r->getID());
+		PilotRecord*s=fLocalDatabase->readRecordById(r->getID());
 		if (s)
 		{
 			// delete the record from the palm
 			s->setAttrib(s->getAttrib() & ~dlpRecAttrDeleted & ~dlpRecAttrDirty);
-			fCurrentDatabase->writeRecord(s);
+			fDatabase->writeRecord(s);
 			KPILOT_DELETE(s);
 		}
 		r->setAttrib(r->getAttrib() & ~dlpRecAttrDeleted & ~dlpRecAttrDirty);
-		fBackupDatabase->writeRecord(r);
+		fLocalDatabase->writeRecord(r);
 	}
 
 	KPILOT_DELETE(r);
@@ -520,10 +554,19 @@ void VCalConduitBase::cleanup()
 {
 	FUNCTIONSETUP;
 
-	KPILOT_DELETE(fCurrentDatabase);
-	KPILOT_DELETE(fBackupDatabase);
-
-	fCalendar->save(fCalendarFile);
+	if (fDatabase) 
+	{
+		fDatabase->resetSyncFlags();
+		fDatabase->cleanUpDatabase();
+	}
+	if (fLocalDatabase) 
+	{
+		fLocalDatabase->resetSyncFlags();
+		fLocalDatabase->cleanUpDatabase();
+	}
+	KPILOT_DELETE(fDatabase);
+	KPILOT_DELETE(fLocalDatabase);
+	if (fCalendar) fCalendar->save(fCalendarFile);
 	KPILOT_DELETE(fCalendar);
 	KPILOT_DELETE(fP);
 
@@ -531,11 +574,11 @@ void VCalConduitBase::cleanup()
 }
 
 
-void VCalConduitBase::addRecord(PilotRecord *r)
+KCal::Incidence* VCalConduitBase::addRecord(PilotRecord *r)
 {
 	FUNCTIONSETUP;
 
-	recordid_t id=fBackupDatabase->writeRecord(r);
+	recordid_t id=fLocalDatabase->writeRecord(r);
 #ifdef DEBUG
 	DEBUGCONDUIT<<fname<<": Pilot Record ID="<<r->getID()<<", backup ID="<<id<<endl;
 #endif
@@ -550,10 +593,26 @@ void VCalConduitBase::addRecord(PilotRecord *r)
 		fP->addIncidence(e);
 	}
 	KPILOT_DELETE(de);
+#ifdef DEBUG
+		DEBUGCONDUIT<<fname<<": syncStatus="<<e->syncStatus()<<endl;
+#endif
+	return e;
 }
 
+// return how to resolve conflicts. for now PalmOverrides=0=false, PCOverrides=1=true, Ask=2-> ask the user using a messagebox
+int VCalConduitBase::resolveConflict(KCal::Incidence*e, PilotAppCategory*de) {
+	if (conflictResolution==RES_ASK)
+	{
+		return KMessageBox::warningYesNo(NULL, 
+			i18n("The following item was modified both on the Pilot and on your PC:\nPC entry:\n\t")+e->summary()+i18n("\nPilot entry:\n\t")+getTitle(de)+
+				i18n("\n\nShould the Pilot entry overwrite the PC entry? If you select \"No\", the PC entry will overwrite the Pilot entry."),
+			i18n("Conflicting Entries")
+		)==KMessageBox::No;
+	}
+	return conflictResolution;
+}
 
-void VCalConduitBase::changeRecord(PilotRecord *r,PilotRecord *s)
+KCal::Incidence*VCalConduitBase::changeRecord(PilotRecord *r,PilotRecord *)
 {
 	FUNCTIONSETUP;
 
@@ -563,8 +622,19 @@ void VCalConduitBase::changeRecord(PilotRecord *r,PilotRecord *s)
 	if (e && de)
 	{
 		// TODO: check for conflict, and if there is one, ask for resolution
+		if ( (e->syncStatus()!=KCal::Incidence::SYNCNONE) && (r->getAttrib() &dlpRecAttrDirty) )
+		{
+			// TODO: I have not yet found a way to complete ignore an item
+			if (resolveConflict(e, de))
+			{
+				// PC record takes precedence:
+				KPILOT_DELETE(de);
+				return e;
+			}
+		}
+		// no conflict or conflict resolution says, Palm overwrites, so do it:
 		incidenceFromRecord(e,de);
-		fBackupDatabase->writeRecord(r);
+		fLocalDatabase->writeRecord(r);
 	}
 	else
 	{
@@ -572,10 +642,11 @@ void VCalConduitBase::changeRecord(PilotRecord *r,PilotRecord *s)
 		addRecord(r);
 	}
 	KPILOT_DELETE(de);
+	return e;
 }
 
 
-void VCalConduitBase::deleteRecord(PilotRecord *r, PilotRecord *s)
+KCal::Incidence*VCalConduitBase::deleteRecord(PilotRecord *r, PilotRecord *)
 {
 	FUNCTIONSETUP;
 
@@ -585,7 +656,8 @@ void VCalConduitBase::deleteRecord(PilotRecord *r, PilotRecord *s)
 		// RemoveEvent also takes it out of the calendar.
 		fP->removeIncidence(e);
 	}
-	fBackupDatabase->writeRecord(r);
+	fLocalDatabase->writeRecord(r);
+	return NULL;
 }
 
 
@@ -616,8 +688,8 @@ void VCalConduitBase::deletePalmRecord(KCal::Incidence*e, PilotRecord*s)
 		DEBUGCONDUIT << fname << ": deleting record " << s->getID() << endl;
 #endif
 		s->setAttrib(s->getAttrib() & ~dlpRecAttrDeleted);
-		fCurrentDatabase->writeRecord(s);
-		fBackupDatabase->writeRecord(s);
+		fDatabase->writeRecord(s);
+		fLocalDatabase->writeRecord(s);
 	}
 	else
 	{
@@ -642,14 +714,14 @@ void VCalConduitBase::updateIncidenceOnPalm(KCal::Incidence*e, PilotAppCategory*
 	}
 	PilotRecord*r=recordFromIncidence(de, e);
 
-	// TODO: CHeck for conflict!
+	// TODO: Check for conflict!
 	if (r)
 	{
-		recordid_t id=fCurrentDatabase->writeRecord(r);
+		recordid_t id=fDatabase->writeRecord(r);
 		r->setID(id);
 		r->setAttrib(r->getAttrib() & ~dlpRecAttrDeleted);
-		fBackupDatabase->writeRecord(r);
-//		fCurrentDatabase->writeRecord(r);
+		fLocalDatabase->writeRecord(r);
+//		fDatabase->writeRecord(r);
 		e->setSyncStatus(KCal::Incidence::SYNCNONE);
 		e->setPilotId(id);
 		KPILOT_DELETE(r);
@@ -658,6 +730,15 @@ void VCalConduitBase::updateIncidenceOnPalm(KCal::Incidence*e, PilotAppCategory*
 
 
 // $Log: vcal-conduitbase.cc,v $
+// Revision 1.1.2.7  2002/06/16 11:03:14  kainhofe
+// merged in some changes from the HEAD branch. Also fixed someproblems with retrieving a db from the palm
+//
+// Revision 1.1.2.6  2002/06/15 13:34:15  kainhofe
+// merging in changes from the HEAD branch that should go into 3.0.2
+//
+// Revision 1.1.2.5  2002/06/07 06:50:10  adridg
+// Be safer wrt. pointers (may be NULL if the database is nonexistent)
+//
 // Revision 1.1.2.4  2002/05/03 19:08:52  kainhofe
 // Local timezone from KOrganizer is now used for the sync
 //
