@@ -27,8 +27,10 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org.
 */
 
+#include <config.h>
+
 static const char *interactivesync_id =
-	"$Id: interactiveSync.cc,v 1.11 2002/02/23 20:51:33 adridg Exp $";
+	"$Id: interactiveSync.cc,v 1.11.2.1 2002/12/12 13:27:52 lunakl Exp $";
 
 #include "options.h"
 
@@ -284,7 +286,7 @@ RestoreAction::RestoreAction(KPilotDeviceLink * p, QWidget * visible ) :
 			<< ": Adding " << s << " to restore list." << endl;
 #endif
 
-		qstrcpy(dbi.name, QFile::encodeName(dirname + s));
+		strlcpy(dbi.name, QFile::encodeName(dirname + s), sizeof(dbi.name));
 
 		f = pi_file_open(dbi.name);
 		if (!f)
@@ -484,6 +486,9 @@ nextFile:
 
 
 // $Log: interactiveSync.cc,v $
+// Revision 1.11.2.1  2002/12/12 13:27:52  lunakl
+// strcpy -> strlcpy
+//
 // Revision 1.11  2002/02/23 20:51:33  adridg
 // Handle errors to _get_info better.
 //
