@@ -27,7 +27,7 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 static const char *pilotdaemon_id =
-	"$Id: pilotDaemon.cc,v 1.59.2.2 2002/04/16 19:41:05 adridg Exp $";
+	"$Id: pilotDaemon.cc,v 1.59.2.3 2002/05/09 22:29:33 adridg Exp $";
 
 #ifndef _KPILOT_OPTIONS_H
 #include "options.h"
@@ -413,6 +413,7 @@ void PilotDaemon::showTray()
 	}
 
 	KPilotConfigSettings & config = KPilotConfig::getConfig();
+	// config.reparseConfiguration();
 
 	getPilotSpeed(config);
 
@@ -420,6 +421,16 @@ void PilotDaemon::showTray()
 	fPilotType = KPilotDeviceLink::None;
 	int t = config.getPilotType();
 
+#ifdef DEBUG
+	DEBUGDAEMON << fname
+		<< ": Got configuration "
+		<< fPilotDevice
+		<< " ("
+		<< fPilotType
+		<< ")"
+		<< endl;
+#endif
+
 	switch (t)
 	{
 	case 0:
@@ -823,6 +834,7 @@ int main(int argc, char **argv)
 	//
 	{
 		KPilotConfigSettings & c = KPilotConfig::getConfig();
+		c.setReadOnly(true);
 
 		if (c.getVersion() < KPilotConfig::ConfigurationVersion)
 		{
@@ -865,6 +877,9 @@ int main(int argc, char **argv)
 
 
 // $Log: pilotDaemon.cc,v $
+// Revision 1.59.2.3  2002/05/09 22:29:33  adridg
+// Various small things not important for the release
+//
 // Revision 1.59.2.2  2002/04/16 19:41:05  adridg
 // Make default sync a HotSync instead of Test
 //
