@@ -3,7 +3,7 @@
   FILE: sspm.c Parse Mime
   CREATOR: eric 25 June 2000
   
-  $Id: sspm.c,v 1.2 2001/01/12 09:56:09 cschumac Exp $
+  $Id: sspm.c,v 1.4.4.2 2002/12/15 22:59:31 waba Exp $
   $Locker:  $
     
  The contents of this file are subject to the Mozilla Public License
@@ -39,7 +39,7 @@
 #include <assert.h>
 #include <ctype.h> /* for tolower */
 #include <stdlib.h>   /* for malloc, free */
-
+#include <string.h> /* for strcasecmp */
 
 #ifdef DMALLOC
 #include "dmalloc.h"
@@ -489,7 +489,7 @@ char* sspm_major_type_string(enum sspm_major_type type)
     return major_content_type_map[i].str; /* Should return SSPM_UNKNOWN_MINOR_TYPE */
 }
 
-char* sspm_minor_type_string(enum sspm_major_type type)
+char* sspm_minor_type_string(enum sspm_minor_type type)
 {
     int i;
     for (i=0; minor_content_type_map[i].type !=  SSPM_UNKNOWN_MINOR_TYPE; 
@@ -948,7 +948,8 @@ void sspm_read_header(struct mime_impl *impl,struct sspm_header *header)
 		
 		assert(strlen(buf) < BUF_SIZE);
 		
-		strcpy(header_lines[current_line],buf);
+		strncpy(header_lines[current_line],buf,BUF_SIZE);
+		header_lines[current_line][BUF_SIZE-1] = '\0';
 		
 		break;
 	    }
@@ -983,7 +984,7 @@ void sspm_read_header(struct mime_impl *impl,struct sspm_header *header)
 		
 		assert( strlen(buf_start) + strlen(last_line) < BUF_SIZE);
 		
-		strcat(last_line,buf_start);
+		strncat(last_line,buf_start, BUF_SIZE-strlen(last_line)-1);
 		
 		break;
 	    }
